==> lirc-0.9.2a.tar.bz2: api-docs/html/group__driver__api.js <==
var group__driver__api =
[
    [ "driver.h", "driver_8h.html", null ],
    [ "ir_remote.h", "ir__remote_8h.html", null ],
    [ "lirc_config.h", "lirc__config_8h.html", null ],
    [ "lirc_log.h", "lirc__log_8h.html", null ],
    [ "receive.h", "receive_8h.html", null ],
    [ "serial.h", "serial_8h.html", null ],
    [ "transmit.h", "transmit_8h.html", null ],
    [ "option_t", "structoption__t.html", [
      [ "key", "structoption__t.html#a77ffef1a45ea4d73c9da6de96c12e13a", null ],
      [ "value", "structoption__t.html#a3133b9533f1b24597f947cff736460b2", null ]
    ] ],
    [ "driver", "structdriver.html", [
      [ "api_version", "structdriver.html#a16e4dc8d1f027390afd91294991d932d", null ],
      [ "close_func", "structdriver.html#a5217ca972f2a1fc8e7bc04a67ef73bd7", null ],
      [ "code_length", "structdriver.html#a2ee468d3e45ec38ceb8a8122a721c2ae", null ],
      [ "decode_func", "structdriver.html#a761099e25fcbf8f0ca9a5b45fbd1f5fc", null ],
      [ "deinit_func", "structdriver.html#ac1ac9d52e4ef2c7ce3cd05a3536d7875", null ],
      [ "device", "structdriver.html#aca3bbacc48c5f27dac5568bd658afec8", null ],
      [ "driver_version", "structdriver.html#a2c48ed8680d2f242dd0c018f846551b7", null ],
      [ "drvctl_func", "structdriver.html#a84ea3e16dbac1e5cf03d202f6a68a265", null ],
      [ "fd", "structdriver.html#a277e91c9ef0365654b5412cdcf8cac5f", null ],
      [ "features", "structdriver.html#acefa919d82609175b57967c5249020c0", null ],
      [ "info", "structdriver.html#a6b71523700af552255b059ff51a657e1", null ],
      [ "init_func", "structdriver.html#a5881deaf612c76c067198a3a155cc225", null ],
      [ "name", "structdriver.html#a2d4bc5861fb0d7bb1684e22a16b7d414", null ],
      [ "open_func", "structdriver.html#a2a18e73cac86ce83a5748849f3741c43", null ],
      [ "readdata", "structdriver.html#acceaeac79f85c154d75449977e54e29d", null ],
      [ "rec_func", "structdriver.html#a319f12b62f2271a8249b497eabe45ae5", null ],
      [ "rec_mode", "structdriver.html#ad5d91256e4b5eb5139a6a744cc8204f6", null ],
      [ "resolution", "structdriver.html#a91eef0a66c9eb8ba1d3c8c9f69a1086b", null ],
      [ "send_func", "structdriver.html#a343a64e118c2d03110579124f509c0e2", null ],
      [ "send_mode", "structdriver.html#abad2a6f422a77f0b80848085b2512ca4", null ]
    ] ],
    [ "DRV_ERR_BAD_OPTION", "group__driver__api.html#gae98bd204d31330f5e862817faadf7f85", null ],
    [ "DRV_ERR_BAD_STATE", "group__driver__api.html#gae323c069918a6b718b3bafd6abbef2a2", null ],
    [ "DRV_ERR_NOT_IMPLEMENTED", "group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9", null ],
    [ "DRV_ERR_NOT_IMPLEMENTED", "group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9", null ],
    [ "DRVCTL_GET_STATE", "group__driver__api.html#ga3637dcda1fb5508e6f51a39b0cc048a7", null ],
    [ "DRVCTL_MAX", "group__driver__api.html#ga2628a2556297a773cddc0848db200d1a", null ],
    [ "DRVCTL_SEND_SPACE", "group__driver__api.html#ga2d4b7ac43bc60cf3d930431f79b2fb89", null ],
    [ "DRVCTL_SET_OPTION", "group__driver__api.html#ga1033feec74cbc16e939d713be2c5b8e0", null ],
    [ "MIN_RECEIVE_TIMEOUT", "group__driver__api.html#ga69de338dd3e47a8275e7821c54d3523e", null ],
    [ "decode_all", "group__driver__api.html#gae334c37e486ce414abf272d4850df6c4", null ],
    [ "default_close", "group__driver__api.html#ga683dd53e7e5d62746c1a645fe133daf0", null ],
    [ "default_drvctl", "group__driver__api.html#ga96e3243bc45ff488f6c55dde5e9b377b", null ],
    [ "default_open", "group__driver__api.html#gac0f7baaef9fe524365c16022001804d3", null ],
    [ "drv_handle_options", "group__driver__api.html#gaae1b223d2bd3a0d0be6e77019c9a976c", null ],
    [ "get_code_by_name", "group__driver__api.html#gafaa7cb5587a3c58e3e825411b966738a", null ],
    [ "get_filter_parameters", "group__driver__api.html#ga1a1b6c86d0309f25ab5806a5f861692c", null ],
    [ "get_frequency_range", "group__driver__api.html#ga19bab2135ca2b7f68dc0b2f8cde9863f", null ],
    [ "get_ir_remote", "group__driver__api.html#ga251129673cd73c5f869bb53c6c38a88f", null ],
    [ "ir_remote_init", "group__driver__api.html#ga8d5bc121b8582a690000bc8befe13080", null ],
    [ "is_in_remotes", "group__driver__api.html#gaadf09b8ef4b71be00f8e53a39f70d315", null ],
    [ "map_code", "group__driver__api.html#gabac8048f405d0a78fcc01fa9ef1132df", null ],
    [ "map_gap", "group__driver__api.html#gac691a06cc99d8c914e2c7451407f245a", null ],
    [ "rec_buffer_clear", "group__driver__api.html#gae96f4130a6ebac0570094820b39ae11c", null ],
    [ "rec_buffer_init", "group__driver__api.html#gad2f7ee8888cb720cdf2be99b11f5230b", null ],
    [ "rec_buffer_reset_wptr", "group__driver__api.html#ga74266da334332e934158389894ddb7c4", null ],
    [ "rec_buffer_rewind", "group__driver__api.html#ga3367c6a318967cb750f67d95d43d3102", null ],
    [ "rec_buffer_set_logfile", "group__driver__api.html#ga0055fe8b9e15df2483fac31e79f8276a", null ],
    [ "receive_decode", "group__driver__api.html#gad89c025d8cc9f77d9d5597da2e420917", null ],
    [ "send_buffer_data", "group__driver__api.html#gadb07368a083899a483af5a223860a9bf", null ],
    [ "send_buffer_init", "group__driver__api.html#ga85a7e2c6a62aab93aaa6453dea381112", null ],
    [ "send_buffer_length", "group__driver__api.html#gabb52ab81437999a59abe9f5e4043174d", null ],
    [ "send_buffer_put", "group__driver__api.html#ga0d43b932c9b39d14e675dbd9507f3997", null ],
    [ "send_buffer_sum", "group__driver__api.html#gab85148382a321609490463510f7a9af3", null ],
    [ "send_ir_ncode", "group__driver__api.html#ga51d2eb6ccf92c9210c69cd727b712bae", null ],
    [ "tty_clear", "group__driver__api.html#gaa680ad6c63aaac541fc85d61b73a46d1", null ],
    [ "tty_create_lock", "group__driver__api.html#gaa2128e719d5174e1210fcc8c532c82bd", null ],
    [ "tty_delete_lock", "group__driver__api.html#ga94d6aff1542d08fcf32b5acdc735090e", null ],
    [ "tty_read", "group__driver__api.html#ga76ea8c360d88f108399c5926b3bff16d", null ],
    [ "tty_reset", "group__driver__api.html#ga2cad04de039521ac1b0c14c42ba1b43c", null ],
    [ "tty_set", "group__driver__api.html#ga17fb600e510ec6919659e7fab74c3de6", null ],
    [ "tty_setbaud", "group__driver__api.html#ga44b60aca788c92e31b61298f534d2b2c", null ],
    [ "tty_setcsize", "group__driver__api.html#gaffeab51b57e1e8eaca6fc502f99e6c29", null ],
    [ "tty_setdtr", "group__driver__api.html#ga7c9acb60305177b4498553782eb4fa3c", null ],
    [ "tty_setrtscts", "group__driver__api.html#gafcab1b890be0e097640ff31f866ab94c", null ],
    [ "tty_write", "group__driver__api.html#ga03233443b447b2de3a81b77a317663c4", null ],
    [ "tty_write_echo", "group__driver__api.html#ga855e6cb4247f8359643a184a912d754d", null ],
    [ "waitfordata", "group__driver__api.html#gadcb46dccea6a4f82bebda46e51945819", null ],
    [ "write_message", "group__driver__api.html#ga04461705747fd8521d369ee96ed762fe", null ],
    [ "last_remote", "group__driver__api.html#ga474c489cabdaae4546ca0ac26ec9cd87", null ],
    [ "repeat_code", "group__driver__api.html#ga2da0e0383db556d0e1ba7261763815c5", null ],
    [ "repeat_remote", "group__driver__api.html#ga7bc28a85da7d0ccf4466708918f01dc4", null ]
];

==> lirc-0.9.3a.tar.bz2: api-docs/html/group__driver__api.js <==
var group__driver__api =
[
    [ "driver.h", "driver_8h.html", null ],
    [ "ir_remote.h", "ir__remote_8h.html", null ],
    [ "lirc_config.h", "lirc__config_8h.html", null ],
    [ "lirc_log.h", "lirc__log_8h.html", null ],
    [ "receive.h", "receive_8h.html", null ],
    [ "serial.h", "serial_8h.html", null ],
    [ "transmit.h", "transmit_8h.html", null ],
    [ "option_t", "structoption__t.html", [
      [ "key", "structoption__t.html#a77ffef1a45ea4d73c9da6de96c12e13a", null ],
      [ "value", "structoption__t.html#a3133b9533f1b24597f947cff736460b2", null ]
    ] ],
    [ "driver", "structdriver.html", [
      [ "api_version", "structdriver.html#a16e4dc8d1f027390afd91294991d932d", null ],
      [ "close_func", "structdriver.html#aea9a20decd81cb165101823a40fd29af", null ],
      [ "code_length", "structdriver.html#a2ee468d3e45ec38ceb8a8122a721c2ae", null ],
      [ "decode_func", "structdriver.html#a4c8fb1671a48fb248bc8dafa90cded15", null ],
      [ "deinit_func", "structdriver.html#a87fb83240c2426874349f860fb8504dc", null ],
      [ "device", "structdriver.html#aca3bbacc48c5f27dac5568bd658afec8", null ],
      [ "driver_version", "structdriver.html#a2c48ed8680d2f242dd0c018f846551b7", null ],
      [ "drvctl_func", "structdriver.html#ac5d035961037ecb0a74182dd456ced26", null ],
      [ "fd", "structdriver.html#a277e91c9ef0365654b5412cdcf8cac5f", null ],
      [ "features", "structdriver.html#acefa919d82609175b57967c5249020c0", null ],
      [ "info", "structdriver.html#a6b71523700af552255b059ff51a657e1", null ],
      [ "init_func", "structdriver.html#a8f50bcc4e1d143a05dd4eba66a4fa7bb", null ],
      [ "name", "structdriver.html#a2d4bc5861fb0d7bb1684e22a16b7d414", null ],
      [ "open_func", "structdriver.html#aeea866dd70c1cb8296e99fbe706bacf5", null ],
      [ "readdata", "structdriver.html#a6dc74317e7f5fff8153be89153766865", null ],
      [ "rec_func", "structdriver.html#a41e193204b057873b878b1979c309db8", null ],
      [ "rec_mode", "structdriver.html#ad5d91256e4b5eb5139a6a744cc8204f6", null ],
      [ "resolution", "structdriver.html#a91eef0a66c9eb8ba1d3c8c9f69a1086b", null ],
      [ "send_func", "structdriver.html#a90d38db70255ee7d38bcd81c9edd9412", null ],
      [ "send_mode", "structdriver.html#abad2a6f422a77f0b80848085b2512ca4", null ]
    ] ],
    [ "DRV_ERR_BAD_OPTION", "group__driver__api.html#gae98bd204d31330f5e862817faadf7f85", null ],
    [ "DRV_ERR_BAD_STATE", "group__driver__api.html#gae323c069918a6b718b3bafd6abbef2a2", null ],
    [ "DRV_ERR_BAD_VALUE", "group__driver__api.html#ga548694fee71123534ede5e27aa4e7e1f", null ],
    [ "DRV_ERR_NOT_IMPLEMENTED", "group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9", null ],
    [ "DRV_ERR_NOT_IMPLEMENTED", "group__driver__api.html#gab58e0aa64a0fc3769c30e60aaf7061e9", null ],
    [ "DRVCTL_GET_STATE", "group__driver__api.html#ga3637dcda1fb5508e6f51a39b0cc048a7", null ],
    [ "DRVCTL_MAX", "group__driver__api.html#ga2628a2556297a773cddc0848db200d1a", null ],
    [ "DRVCTL_SEND_SPACE", "group__driver__api.html#ga2d4b7ac43bc60cf3d930431f79b2fb89", null ],
    [ "DRVCTL_SET_OPTION", "group__driver__api.html#ga1033feec74cbc16e939d713be2c5b8e0", null ],
    [ "MIN_RECEIVE_TIMEOUT", "group__driver__api.html#ga69de338dd3e47a8275e7821c54d3523e", null ],
    [ "decode_all", "group__driver__api.html#gae334c37e486ce414abf272d4850df6c4", null ],
    [ "default_close", "group__driver__api.html#ga683dd53e7e5d62746c1a645fe133daf0", null ],
    [ "default_drvctl", "group__driver__api.html#ga96e3243bc45ff488f6c55dde5e9b377b", null ],
    [ "default_open", "group__driver__api.html#gac0f7baaef9fe524365c16022001804d3", null ],
    [ "drv_handle_options", "group__driver__api.html#gaae1b223d2bd3a0d0be6e77019c9a976c", null ],
    [ "get_code_by_name", "group__driver__api.html#gafaa7cb5587a3c58e3e825411b966738a", null ],
    [ "get_decoding", "group__driver__api.html#gaf2e0b982088d231116dea399afa8597f", null ],
    [ "get_filter_parameters", "group__driver__api.html#ga1a1b6c86d0309f25ab5806a5f861692c", null ],
    [ "get_frequency_range", "group__driver__api.html#ga19bab2135ca2b7f68dc0b2f8cde9863f", null ],
    [ "get_ir_remote", "group__driver__api.html#ga251129673cd73c5f869bb53c6c38a88f", null ],
    [ "ir_remote_init", "group__driver__api.html#ga8d5bc121b8582a690000bc8befe13080", null ],
    [ "is_in_remotes", "group__driver__api.html#gaadf09b8ef4b71be00f8e53a39f70d315", null ],
    [ "map_code", "group__driver__api.html#gabac8048f405d0a78fcc01fa9ef1132df", null ],
    [ "map_gap", "group__driver__api.html#gac691a06cc99d8c914e2c7451407f245a", null ],
    [ "ncode_dup", "group__driver__api.html#gac288bce2140d2066a3990a1b2e3317c5", null ],
    [ "ncode_free", "group__driver__api.html#ga4477860d1f604548e032694de8f69c16", null ],
    [ "rec_buffer_clear", "group__driver__api.html#gae96f4130a6ebac0570094820b39ae11c", null ],
    [ "rec_buffer_init", "group__driver__api.html#gabc294def4957afc161909b72e1348835", null ],
    [ "rec_buffer_reset_wptr", "group__driver__api.html#ga74266da334332e934158389894ddb7c4", null ],
    [ "rec_buffer_rewind", "group__driver__api.html#ga3367c6a318967cb750f67d95d43d3102", null ],
    [ "rec_buffer_set_logfile", "group__driver__api.html#ga0055fe8b9e15df2483fac31e79f8276a", null ],
    [ "rec_set_update_mode", "group__driver__api.html#gaa491fcec2fc35512ff2964dc208edcca", null ],
    [ "receive_decode", "group__driver__api.html#gad89c025d8cc9f77d9d5597da2e420917", null ],
    [ "send_buffer_data", "group__driver__api.html#ga4871fa572fb913f068f0e3c75d3fdc41", null ],
    [ "send_buffer_init", "group__driver__api.html#ga85a7e2c6a62aab93aaa6453dea381112", null ],
    [ "send_buffer_length", "group__driver__api.html#gae40fd0e37871cd30a43b3b2bc3c4336c", null ],
    [ "send_buffer_put", "group__driver__api.html#ga0d43b932c9b39d14e675dbd9507f3997", null ],
    [ "send_buffer_sum", "group__driver__api.html#ga55e0351346ec0cb553a7f1632db99c57", null ],
    [ "send_ir_ncode", "group__driver__api.html#ga51d2eb6ccf92c9210c69cd727b712bae", null ],
    [ "tty_clear", "group__driver__api.html#gaa680ad6c63aaac541fc85d61b73a46d1", null ],
    [ "tty_create_lock", "group__driver__api.html#gaa2128e719d5174e1210fcc8c532c82bd", null ],
    [ "tty_delete_lock", "group__driver__api.html#ga94d6aff1542d08fcf32b5acdc735090e", null ],
    [ "tty_read", "group__driver__api.html#ga76ea8c360d88f108399c5926b3bff16d", null ],
    [ "tty_reset", "group__driver__api.html#ga2cad04de039521ac1b0c14c42ba1b43c", null ],
    [ "tty_set", "group__driver__api.html#ga17fb600e510ec6919659e7fab74c3de6", null ],
    [ "tty_setbaud", "group__driver__api.html#ga44b60aca788c92e31b61298f534d2b2c", null ],
    [ "tty_setcsize", "group__driver__api.html#gaffeab51b57e1e8eaca6fc502f99e6c29", null ],
    [ "tty_setdtr", "group__driver__api.html#ga7c9acb60305177b4498553782eb4fa3c", null ],
    [ "tty_setrtscts", "group__driver__api.html#gafcab1b890be0e097640ff31f866ab94c", null ],
    [ "tty_write", "group__driver__api.html#ga03233443b447b2de3a81b77a317663c4", null ],
    [ "tty_write_echo", "group__driver__api.html#ga855e6cb4247f8359643a184a912d754d", null ],
    [ "waitfordata", "group__driver__api.html#gadcb46dccea6a4f82bebda46e51945819", null ],
    [ "write_message", "group__driver__api.html#ga04461705747fd8521d369ee96ed762fe", null ],
    [ "last_remote", "group__driver__api.html#ga474c489cabdaae4546ca0ac26ec9cd87", null ],
    [ "repeat_code", "group__driver__api.html#ga2da0e0383db556d0e1ba7261763815c5", null ],
    [ "repeat_remote", "group__driver__api.html#ga7bc28a85da7d0ccf4466708918f01dc4", null ]
];
